emaillib package
================

Submodules
----------

emaillib.emaillib module
------------------------

.. automodule:: emaillib.emaillib
    :members:
    :undoc-members:
    :show-inheritance:

emaillib.emaillibexceptions module
----------------------------------

.. automodule:: emaillib.emaillibexceptions
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: emaillib
    :members:
    :undoc-members:
    :show-inheritance:
